@@ -32,6 +32,8 @@ class ReplayBuffer(S):
 
         self.device = device
         self.max_size = size
+        self.data = {k: None for k in self.off_policy_data_fields}  # lazy init
+
         self.reset()
 
     @classmethod
@@ -71,14 +73,15 @@ class ReplayBuffer(S):
         self.data["rew"] = np.zeros((self.max_size, *sample["rew"].shape), dtype=np.float32)
         self.data["done"] = np.zeros((self.max_size, *sample["done"].shape), dtype=np.float32)
 
-    def get_data(self):
+    def get_data(self, data_to_cpu=False):
         """Return currently stored data."""
-        return {k: v[0:self.step] for k, v in self.data.items() if v is not None}
+        if data_to_cpu: data = {k: v for k, v in self.data.items() if v is not None}
+        else: data = {k: v for k, v in self.data.items() if v is not None}
+        return data
 
     def reset(self):
         """Set class counters to zero and remove stored data"""
         self.step, self.size = 0, 0
-        self.data = {k: None for k in self.off_policy_data_fields} # lazy init
 
     def add_data(self, new_data):
         """
